Improve this Doc View Source

Factory function used to create XMLHttpRequest objects.

Replace or decorate this service to create your own custom XMLHttpRequest objects.

    angular.module('myApp', [])
    .factory('$xhrFactory', function() {
      return function createXhr(method, url) {
        return new window.XMLHttpRequest({mozSystem: true});
      };
    });

## Usage

`$xhrFactory(method, url);`

### Arguments

Param | Type | Details
--- | --- | ---
method | string | HTTP method of the request (GET, POST, PUT, ..)
url | string | URL of the request.